function ns = pc(G, i)
%PC Find parents and children of node in undirected graph 
%
%   IND = PC(G, I) returns the list of parents and children of node I in 
%   graph G in row vector IND. Only the lower triangular of G is used.
%
%   Example:
%       
%       % create an undirected graph with 4 nodes
%       G = sparse([1 1 2 3], [2 3 4 4], ones(1, 4), 4, 4);
%       G = G | G'; % make symmetric
%
%       % find parents and children of node #2
%       pc = org.mensxmachina.commons.graph.pc(G, 2)

%   Copyright 2010 Mens X Machina
%
%   This file is part of Mens X Machina Commons Toolbox.
%
%   Mens X Machina Commons Toolbox is free software: you can redistribute
%   it and/or modify it under the terms of the GNU General Public License 
%   as published by the Free Software Foundation, either version 3 of the
%   License, or (at your option) any later version.
%
%   Mens X Machina Commons Toolbox is distributed in the hope that it will
%   be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
%   of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
%   General Public License for more details.
%
%   You should have received a copy of the GNU General Public License
%   along with Mens X Machina Commons Toolbox. If not, see
%   <http://www.gnu.org/licenses/>.

ns = find(G(i, :));
