function S = skeleton(G)
%SKELETON Returns the skeleton of a graph
%
%   S = SKELETON(G) returns the skeleton S of graph G. S is a symmetric 
%   logical matrix with ones corresponding to the edges in G.
%
%   Example:
%       
%       % create a directed graph with 4 nodes
%       G = sparse([1 1 2 3], [2 3 4 4], ones(1, 4), 4, 4);
%
%       % view graph
%       view(biograph(G));    
%
%       % get graph skeleton
%       ps = org.mensxmachina.commons.graph.skeleton(G)

%   Copyright 2010 Mens X Machina
%
%   This file is part of Mens X Machina Commons Toolbox.
%
%   Mens X Machina Commons Toolbox is free software: you can redistribute
%   it and/or modify it under the terms of the GNU General Public License 
%   as published by the Free Software Foundation, either version 3 of the
%   License, or (at your option) any later version.
%
%   Mens X Machina Commons Toolbox is distributed in the hope that it will
%   be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
%   of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
%   General Public License for more details.
%
%   You should have received a copy of the GNU General Public License
%   along with Mens X Machina Commons Toolbox. If not, see
%   <http://www.gnu.org/licenses/>.

S = G | G';

end
