function nlevels = nlevels(a)
%NLEVELS Get number of levels
%   B = NLEVELS(A) returns in row vector B the number of levels of each
%   variable of the categorical dataset or matrix A. If A is a categorical
%   dataset, each element of NLEVELS contains the number of levels of the
%   corresponding variable of the dataset. If A is a matrix, each element
%   of NLEVELS contains the maximum value of the corresponding column of A.

%   Copyright 2010 Mens X Machina
%
%   This file is part of Mens X Machina Commons Toolbox.
%
%   Mens X Machina Commons Toolbox is free software: you can redistribute
%   it and/or modify it under the terms of the GNU General Public License 
%   as published by the Free Software Foundation, either version 3 of the
%   License, or (at your option) any later version.
%
%   Mens X Machina Commons Toolbox is distributed in the hope that it will
%   be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
%   of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
%   General Public License for more details.
%
%   You should have received a copy of the GNU General Public License
%   along with Mens X Machina Commons Toolbox. If not, see
%   <http://www.gnu.org/licenses/>.

assert( isa(a, 'dataset') || util.issubs(a) );

if isa(a, 'dataset')
    
    varnames = get(a, 'VarNames');
    
    ncols = size(a, 2);
    
    nlevels = zeros(1, ncols);
    
    for j=1:ncols
        
        column = a.(varnames{j});
        
        assert( isa(column, 'categorical') );
        
        nlevels(j) = length(getlabels(column));
        
    end

else

    nlevels = max(a);
    
end
    
end
