function [tpr fpr threshold] = plotroc(targets, outputs)
%PLOTROC Plot receiver operating characteristic
%
%   PLOTROC is called just like ORG.MENSXMACHINA.COMMONS.STATS.ROC, but it
%   also plots the Receiver Operating Characteristic.
%
%   See also:
%       ORG.MENSXMACHINA.COMMONS.STATS.ROC,
%       ORG.MENSXMACHINA.COMMONS.STATS.AUC

%   Copyright 2010 Mens X Machina
%
%   This file is part of Mens X Machina Commons Toolbox.
%
%   Mens X Machina Commons Toolbox is free software: you can redistribute
%   it and/or modify it under the terms of the GNU General Public License 
%   as published by the Free Software Foundation, either version 3 of the
%   License, or (at your option) any later version.
%
%   Mens X Machina Commons Toolbox is distributed in the hope that it will
%   be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
%   of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
%   General Public License for more details.
%
%   You should have received a copy of the GNU General Public License
%   along with Mens X Machina Commons Toolbox. If not, see
%   <http://www.gnu.org/licenses/>.

[tpr fpr threshold] = ...
        org.mensxmachina.commons.stats.roc(targets, outputs);
    
if ~iscell(tpr)
    
    plot(fpr, tpr);
    
else

    for i=1:length(fpr)
        
        plot(fpr{i}, tpr{i});
        hold all;
    
    end
    
end

xlim([0 1]);
ylim([0 1]);

title('ROC');
xlabel('False Positive Rate');
ylabel('True Positive Rate');

hold off;

end