classdef TestChi2Test < TestCase
%TESTCHI2TEST chi2test test cases
%   Note: Requires Causal Explorer to be in the path.

    properties(Access=private)
        data
    end

    methods

    function obj = TestChi2Test(name)
        
        obj = obj@TestCase(name);
        
        % create dataset
        
        data1 = randint(10000, 1, 2);
        data2 = randint(10000, 1, 2); % I(1;2)
        data3 = data1 + 1; % ~I(1;3)
        data4 = data1/2; % ~I(1;3) but I(1;3|4)
        data5 = data1 + data2; % I(1;2) but ~I(1;2|5)
        
        obj.data = dataset(nominal(data1), nominal(data2), nominal(data3), nominal(data4), nominal(data5));
        
    end
    
    function testi12givenempty(obj)
        [h p stats] = org.mensxmachina.commons.stats.chi2test(obj.data, 1, 2);
        assertTrue( h == 0 );
    end
    
    function testd13givenempty(obj)
        [h p stats] = org.mensxmachina.commons.stats.chi2test(obj.data, 1, 3);
        assertTrue( h == 1 );
    end
    
    function testi13given4(obj)
        [h p stats] = org.mensxmachina.commons.stats.chi2test(obj.data, 1, 3, 4);
        assertTrue( h == 0 );
    end
    
    function testd12given5(obj)
        [h p stats] = org.mensxmachina.commons.stats.chi2test(obj.data, 1, 2, 5);
        assertTrue( h == 1 );
    end
    
    function testopt(obj)
        
        a = 1;
        b = 2;
        s = 5;
        
        alpha = 0.05;
        omin = 5;
        subs = double(obj.data);
        nLevels = org.mensxmachina.commons.stats.nlevels(obj.data);
        
        org.mensxmachina.commons.stats.chi2testopt( ...
            subs, nLevels, a, b, s, alpha, omin, 'g2', false);
            
    end
    
    function testcmpwithce(obj)
        % compare with Causal Explorer's G2TEST_2()
        
        a = 1;
        b = 2;
        s = 5;
        
        alpha = 0.05;
        omin = 5;
        nLevels = org.mensxmachina.commons.stats.nlevels(obj.data);
        
        ss = [100 1000 10000];
        %ss = 10000;
        numSS = numel(ss);
        numRepeats = 1000;
        
        time_ss = zeros(1, numSS);
        time_ss_ce = zeros(1, numSS);
        
        for i=1:numSS
            
            data = obj.data(1:ss(i), :);
            subs = double(data);
            
            start = cputime;
            
            for j=1:numRepeats
                
                [h p stats] = org.mensxmachina.commons.stats.chi2test( ...
                    obj.data, a, b, s, ...
                    'alpha', alpha, 'stat', 'g2', 'omin', omin, ...
                    'subs', subs, 'nlevels', nLevels);

            end
            
            time_ss(i) = cputime - start;
            
            data = subs - 1;
            
            start = cputime;
            
            for j=1:numRepeats
                
                [p_ce, G2_ce, exit_flag] = g2test_2(a, b, s, data, nLevels);
                
            end
            
            time_ss_ce(i) = cputime - start;

            %{
            if isnan(p)

                disp('p-value = NaN');

                assertTrue( exit_flag == 0 );
                assertTrue( isnan(p_ce) );

            else

                tol = 1e-6;

                assertElementsAlmostEqual(p, p_ce, 'absolute', tol);
                assertElementsAlmostEqual(stats.g2stat, G2_ce, 'absolute', tol);

            end
            %}
            
        end
        
        disp('Time difference CE-MxM %');
        ((time_ss_ce - time_ss) ./ time_ss_ce) * 100
        
            
    end
    
    end
  
end 
