classdef TestGrpStatPlot < TestCase
%TESTGRPSTATPLOT grpstatplot test cases

properties
    
    xGroupVar_numeric
    xGroupVar_nominal
    xGroupVar_cellstr
    xGroupVar
    
    legendGroupVar_numeric
    legendGroupVar_nominal
    legendGroupVar_cellstr
    legendGroupVar
    
    var
    
    a_matrix
    a_dataset
    
    mean_xGroupVar
    mean_legendGroupVar_xGroupVar

end

methods

function obj = TestGrpStatPlot(name)

obj = obj@TestCase(name);

obj.xGroupVar_numeric = ...
    struct('name', 'xGroupVar_numeric', 'ind', 1, ...
        'specifiers', {{1, 'xGroupVar_numeric'}});

obj.xGroupVar_nominal = ...
    struct('name', 'xGroupVar_nominal', 'ind', 2, ...
        'specifiers', {{2, 'xGroupVar_nominal'}});

obj.xGroupVar_cellstr = ...
    struct('name', 'xGroupVar_cellstr', 'ind', 3, ...
        'specifiers', {{3, 'xGroupVar_cellstr'}});    
    
obj.xGroupVar = ...
    [ obj.xGroupVar_numeric obj.xGroupVar_nominal obj.xGroupVar_cellstr ];

obj.legendGroupVar_numeric = ...
    struct('name', 'legendGroupVar_numeric', 'ind', 4, ...
        'specifiers', {{4, 'legendGroupVar_numeric'}});

obj.legendGroupVar_nominal = ...
    struct('name', 'legendGroupVar_nominal', 'ind', 5, ...
        'specifiers', {{5, 'legendGroupVar_nominal'}});

obj.legendGroupVar_cellstr = ...
    struct('name', 'legendGroupVar_cellstr', 'ind', 6, ...
        'specifiers', {{6, 'legendGroupVar_cellstr'}});    
    
obj.legendGroupVar = ...
    [ obj.legendGroupVar_numeric obj.legendGroupVar_nominal obj.legendGroupVar_cellstr ];

obj.var = ...
    struct('name', 'var', 'ind', 7, 'specifiers', {{7, 'var'}});

xGroupVar_numeric = [ 1 1 2 2 3 3 ]';
xGroupVar_nominal = nominal(xGroupVar_numeric, {'a','b','c'});
xGroupVar_cellstr = { 'a'; 'a'; 'b'; 'b'; 'c'; 'c'; };

% reverse in order to check sorted output
xGroupVar_numeric = xGroupVar_numeric(end:-1:1);
xGroupVar_nominal = xGroupVar_nominal(end:-1:1);
xGroupVar_cellstr = xGroupVar_cellstr(end:-1:1);

legendGroupVar_numeric = [ 1 2 1 2 1 2 ]';
legendGroupVar_nominal = nominal(legendGroupVar_numeric, {'a','b'});
legendGroupVar_cellstr = { 'a'; 'b'; 'a'; 'b'; 'a'; 'b'; };

% reverse in order to check sorted output
legendGroupVar_numeric = legendGroupVar_numeric(end:-1:1);
legendGroupVar_nominal = legendGroupVar_nominal(end:-1:1);
legendGroupVar_cellstr = legendGroupVar_cellstr(end:-1:1);

var = (6:-1:1)';

% create dataset
obj.a_dataset = dataset( ...
    xGroupVar_numeric, xGroupVar_nominal, xGroupVar_cellstr, ...
    legendGroupVar_numeric, legendGroupVar_nominal, legendGroupVar_cellstr, ...
    var);

% create matrix
obj.a_matrix = [ ...
    repmat(double(xGroupVar_numeric), 1, 3) ...
    repmat(double(legendGroupVar_numeric), 1, 3) ...
    var];

% correct mean_xGroupVar
obj.mean_xGroupVar = [1.5 3.5 5.5]';
obj.mean_legendGroupVar_xGroupVar = [1 3 5 2 4 6]';

end

function testMatrixSingleGroupVarDefaults(obj)
close all;
figure;
[h b] = org.mensxmachina.commons.stats.grpstatplot(...
    obj.a_matrix, obj.xGroupVar_numeric.ind, obj.var.ind);
assertTrue( isequal(b, obj.mean_xGroupVar) );
end

function testMatrixSingleGroupVarStd(obj)
close all;
figure;
[h b] = org.mensxmachina.commons.stats.grpstatplot(...
    obj.a_matrix, obj.xGroupVar_numeric.ind, obj.var.ind, 'errorstat', @std);
assertTrue( isequal(b, obj.mean_xGroupVar) );
end

function testMatrixSingleGroupVarRange(obj)
close all;
figure;
[h b] = org.mensxmachina.commons.stats.grpstatplot(...
    obj.a_matrix, obj.xGroupVar_numeric.ind, obj.var.ind, 'errorstat', @TestGrpStatPlot.range);
assertTrue( isequal(b, obj.mean_xGroupVar) );
end

function testMatrixTwoGroupVarsDefaults(obj)
close all;
figure;
[h b] = org.mensxmachina.commons.stats.grpstatplot(...
    obj.a_matrix, obj.legendGroupVar_numeric.ind, obj.xGroupVar_numeric.ind, obj.var.ind);
assertTrue( isequal(b, obj.mean_legendGroupVar_xGroupVar) );
end

function testMatrixTwoGroupVarStd(obj)
close all;
figure;
[h b] = org.mensxmachina.commons.stats.grpstatplot(...
    obj.a_matrix, obj.legendGroupVar_numeric.ind, obj.xGroupVar_numeric.ind, obj.var.ind, 'errorstat', @std)
assertTrue( isequal(b, obj.mean_legendGroupVar_xGroupVar) );
end

function testMatrixTwoGroupVarRange(obj)
close all;
figure;
[h b] = org.mensxmachina.commons.stats.grpstatplot(...
    obj.a_matrix, obj.legendGroupVar_numeric.ind, obj.xGroupVar_numeric.ind, obj.var.ind, 'errorstat', @TestGrpStatPlot.range)
assertTrue( isequal(b, obj.mean_legendGroupVar_xGroupVar) );
end

function testDatasetSingleGroupVarDefaults(obj)
close all;
for i=1:numel(obj.xGroupVar) % for all X grouping variables
    for j=1:numel(obj.xGroupVar(i).specifiers) % for both grouping variable specifiers
        for k=1:numel(obj.var.specifiers) % for both variable specifiers
            figure;
            [h b] = org.mensxmachina.commons.stats.grpstatplot(...
                obj.a_dataset, ...
                obj.xGroupVar(i).specifiers{j}, ...
                obj.var.specifiers{k})
            assertTrue( isequal(double(b(:, 3)), obj.mean_xGroupVar) );
        end
    end
end
end

function testDatasetSingleGroupVarStd(obj)
close all;
for i=1:numel(obj.xGroupVar) % for all X grouping variables
    for j=1:numel(obj.xGroupVar(i).specifiers) % for both grouping variable specifiers
        for k=1:numel(obj.var.specifiers) % for both variable specifiers
            figure;
            [h b] = org.mensxmachina.commons.stats.grpstatplot(...
                obj.a_dataset, ...
                obj.xGroupVar(i).specifiers{j}, ...
                obj.var.specifiers{k}, ...
                'errorstat', @std)
            assertTrue( isequal(double(b(:, 3)), obj.mean_xGroupVar) );
        end
    end
end
end

function testDatasetSingleGroupVarRange(obj)
close all;
for i=1:numel(obj.xGroupVar) % for all X grouping variables
    for j=1:numel(obj.xGroupVar(i).specifiers) % for both grouping variable specifiers
        for k=1:numel(obj.var.specifiers) % for both variable specifiers
            figure;
            [h b] = org.mensxmachina.commons.stats.grpstatplot(...
                obj.a_dataset, ...
                obj.xGroupVar(i).specifiers{j}, ...
                obj.var.specifiers{k}, ...
                'errorstat', @TestGrpStatPlot.range)
            assertTrue( isequal(double(b(:, 3)), obj.mean_xGroupVar) );
        end
    end
end
end

function testDatasetTwoGroupVarsDefaults(obj)
close all;
for i=1:numel(obj.xGroupVar) % for all X grouping variables
    for j=1:numel(obj.xGroupVar(i).specifiers) % for both grouping variable specifiers
        for k=1:numel(obj.legendGroupVar) % for all legend grouping variables
            for l=1:numel(obj.legendGroupVar(i).specifiers) % for both grouping variable specifiers
                for m=1:numel(obj.var.specifiers) % for both variable specifiers
                    figure;
                    obj.legendGroupVar(k).specifiers{l}
                    obj.xGroupVar(i).specifiers{j}
                    obj.var.specifiers{m}
                    [h b] = org.mensxmachina.commons.stats.grpstatplot(...
                        obj.a_dataset, ...
                        obj.legendGroupVar(k).specifiers{l}, ...
                        obj.xGroupVar(i).specifiers{j}, ...
                        obj.var.specifiers{m})
                    assertTrue( isequal(double(b(:, 4)), obj.mean_legendGroupVar_xGroupVar) );
                end
            end
        end
    end
    close all;
end
end

function testDatasetTwoGroupVarsStd(obj)
close all;
for i=1:numel(obj.xGroupVar) % for all X grouping variables
    for j=1:numel(obj.xGroupVar(i).specifiers) % for both grouping variable specifiers
        for k=1:numel(obj.legendGroupVar) % for all legend grouping variables
            for l=1:numel(obj.legendGroupVar(i).specifiers) % for both grouping variable specifiers
                for m=1:numel(obj.var.specifiers) % for both variable specifiers
                    figure;
                    obj.legendGroupVar(k).specifiers{l}
                    obj.xGroupVar(i).specifiers{j}
                    obj.var.specifiers{m}
                    [h b] = org.mensxmachina.commons.stats.grpstatplot(...
                        obj.a_dataset, ...
                        obj.legendGroupVar(k).specifiers{l}, ...
                        obj.xGroupVar(i).specifiers{j}, ...
                        obj.var.specifiers{m}, ...
                        'errorstat', @std)
                    assertTrue( isequal(double(b(:, 4)), obj.mean_legendGroupVar_xGroupVar) );
                end
            end
        end
    end
    close all;
end
end

function testDatasetTwoGroupVarsRange(obj)
close all;
for i=1:numel(obj.xGroupVar) % for all X grouping variables
    for j=1:numel(obj.xGroupVar(i).specifiers) % for both grouping variable specifiers
        for k=1:numel(obj.legendGroupVar) % for all legend grouping variables
            for l=1:numel(obj.legendGroupVar(i).specifiers) % for both grouping variable specifiers
                for m=1:numel(obj.var.specifiers) % for both variable specifiers
                    figure;
                    obj.legendGroupVar(k).specifiers{l}
                    obj.xGroupVar(i).specifiers{j}
                    obj.var.specifiers{m}
                    [h b] = org.mensxmachina.commons.stats.grpstatplot(...
                        obj.a_dataset, ...
                        obj.legendGroupVar(k).specifiers{l}, ...
                        obj.xGroupVar(i).specifiers{j}, ...
                        obj.var.specifiers{m}, ...
                        'errorstat', @TestGrpStatPlot.range)
                    assertTrue( isequal(double(b(:, 4)), obj.mean_legendGroupVar_xGroupVar) );
                end
            end
        end
    end
    close all;
end
end

function testNames(obj)
% see output for the correct assignment of the names in the dataset(s)
close all;
names = {'var1_value', 'group_counts', 'meanvar'};
% for one and two group variables, with errorbar or not
[h b] = org.mensxmachina.commons.stats.grpstatplot( ...
    obj.a_dataset, obj.xGroupVar_numeric.name, obj.var.name, 'VarNames', names)
names = {'var1_value', 'group_counts', 'meanvar', 'stdvar'};
[h b] = org.mensxmachina.commons.stats.grpstatplot( ...
    obj.a_dataset, obj.xGroupVar_numeric.name, obj.var.name, 'errorstat', @std, 'VarNames', names)
names = {'var1_value', 'var2_value', 'group_counts', 'meanvar'};
[h b] = org.mensxmachina.commons.stats.grpstatplot( ...
    obj.a_dataset, obj.legendGroupVar_numeric.name, obj.xGroupVar_numeric.name, obj.var.name, 'VarNames', names)
names = {'var1_value', 'var2_value', 'group_counts', 'meanvar', 'stdvar'};
[h b] = org.mensxmachina.commons.stats.grpstatplot( ...
    obj.a_dataset, obj.legendGroupVar_numeric.name, obj.xGroupVar_numeric.name, obj.var.name, 'errorstat', @std, 'VarNames', names)
end
end

methods(Static)

function range = range(a)
    range = [mean(a)-min(a); max(a)-mean(a)];   
end

end

end
